searchData={"content_type":"text/markdown","items":[{"doc":"Copies files according to the given profile's configuration.\n\nUsage:\n\n    $ mix phx.copy PROFILE [PROFILE2 ...]\n\nPrior to running, the given PROFILE must be properly configured in `config/config.exs`.\nSee the documentation of `Phoenix.Copy` for more information.","ref":"Mix.Tasks.Phx.Copy.html","title":"mix phx.copy","type":"task"},{"doc":"Copy static assets for your Phoenix app during development and deployment.\n\nFor more information, see the [README](readme.html).","ref":"Phoenix.Copy.html","title":"Phoenix.Copy","type":"module"},{"doc":"To copy files once, use `run/1` with the name of the configured profile(s):\n\n    run(:default)\n    run([:default, :assets])\n\nTo watch for changes and continually copy files, use `watch/1`:\n\n    watch(:default)\n    watch([:default, :assets])\n\nNote that `watch/1` will block execution.","ref":"Phoenix.Copy.html#module-direct-usage","title":"Direct Usage - Phoenix.Copy","type":"module"},{"doc":"Returns the configuration of the given `profile`.","ref":"Phoenix.Copy.html#config_for!/1","title":"Phoenix.Copy.config_for!/1","type":"function"},{"doc":"Copies files from the configured source and destination for the given `profile`.\n\nReturns a list of copied files.","ref":"Phoenix.Copy.html#run/1","title":"Phoenix.Copy.run/1","type":"function"},{"doc":"Watch for changes in the configured `source` and copy files to the `destination`.\n\nAlso performs an initial copy of the files immediately. Note that this function blocks execution\nuntil the process receives an exit signal.\n\nIf multiple profiles are given, the watcher will watch all of the source directories and react\naccording to the file's closest watched ancestor. This means that watched directories may overlap,\nwith nested sources sending their files to different locations than their ancestors.\n\nAn optional `debounce` time can be configured (in milliseconds) to avoid copying the same file\nmultiple times in a short period. By default, a copy will occur for every filesystem event.","ref":"Phoenix.Copy.html#watch/1","title":"Phoenix.Copy.watch/1","type":"function"},{"doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"* **Add**: Relax constraints to allow version `1.0` of dependency `filesystem` (thanks [@nshafer](https://github.com/nshafer))","ref":"changelog.html#v0-1-4-2024-06-05","title":"v0.1.4 (2024-06-05) - Changelog","type":"extras"},{"doc":"* **Add**: Automatically dereference symlinks during copy (requires Elixir 1.14) (thanks [@derek-zhou](https://github.com/derek-zhou))\n* **Fix**: Choose the correct destination for files with nested watchers with Elixir before 1.12\n* **Fix**: Tests requiring multiple file watchers for the same directory failed on Linux\n* **Fix**: CI did not work due to lack of `inotify-tools`\n* **Fix**: CI now tests against Elixir 1.10 / OTP 21 as well as later versions","ref":"changelog.html#v0-1-3-2023-02-26","title":"v0.1.3 (2023-02-26) - Changelog","type":"extras"},{"doc":"* **Add**: Profiles can include a `debounce` option to avoid duplicate copy events (thanks [@kuon](https://github.com/kuon))","ref":"changelog.html#v0-1-2-2022-12-21","title":"v0.1.2 (2022-12-21) - Changelog","type":"extras"},{"doc":"* **Add**: Run multiple profiles at once in `Phoenix.Copy.run/1`, `Phoenix.Copy.watch/1`, and `mix phx.copy`.\n* **Fix**: Support single-file source and destination paths.","ref":"changelog.html#v0-1-1-2022-07-07","title":"v0.1.1 (2022-07-07) - Changelog","type":"extras"},{"doc":"* **Fix**: Use default latency of 500ms for watcher on macOS to reduce double-copies","ref":"changelog.html#v0-1-0-2022-03-24","title":"v0.1.0 (2022-03-24) - Changelog","type":"extras"},{"doc":"* **Add**: Add some basic tests\n* **Fix**: Removing a file no longer causes an error","ref":"changelog.html#v0-1-0-rc-2-2022-03-24","title":"v0.1.0-rc.2 (2022-03-24) - Changelog","type":"extras"},{"doc":"* **Add**: Perform an initial copy when watcher starts","ref":"changelog.html#v0-1-0-rc-1-2022-03-23","title":"v0.1.0-rc.1 (2022-03-23) - Changelog","type":"extras"},{"doc":"* Initial release\n* **Add**: `mix phx.copy` task\n* **Add**: `Phoenix.Copy.watch/1` with Phoenix Endpoint watcher compatibility","ref":"changelog.html#v0-1-0-rc-0-2022-03-22","title":"v0.1.0-rc.0 (2022-03-22) - Changelog","type":"extras"},{"doc":"# Phoenix Copy\n\n[![Hex.pm](https://img.shields.io/hexpm/v/phoenix_copy)](https://hex.pm/packages/phoenix_copy)\n[![Documentation](https://img.shields.io/badge/hex-docs-blue)](https://hexdocs.pm/phoenix_copy)\n[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)\n\nCopy static assets for your Phoenix app during development and deployment.\n\nThis project provides:\n\n* A mix task `mix phx.copy` for one-time copying of files during deployment\n* Integration with Phoenix watchers to provide continuous copying of files in development\n* The ability to configure multiple sources and destinations for more complex workflows\n\nIt pairs nicely with the Phoenix team's [esbuild](https://github.com/phoenixframework/esbuild) and [tailwind](https://github.com/phoenixframework/tailwind) helpers for a complete asset pipeline.","ref":"readme.html","title":"Phoenix Copy","type":"extras"},{"doc":"If you plan to copy assets in production, then add `phoenix_copy` as a dependency in all environments:\n\n```elixir\ndef deps do\n  [\n    {:phoenix_copy, \"~> 0.1.4\"}\n  ]\nend\n```\n\nOn the other hand, if you only need to copy assets in development, you can install it as a `dev` dependency only:\n\n```elixir\ndef deps do\n  [\n    {:phoenix_copy, \"~> 0.1.3\", only: :dev}\n  ]\nend\n```\n\nAfter installation, `phoenix_copy` requires some configuration.","ref":"readme.html#installation","title":"Installation - Phoenix Copy","type":"extras"},{"doc":"This project uses configuration _profiles_ to allow multiple configurations with the same package.\nTo get started, let's create a profile called `default` in the app's configuration:\n\n```elixir\nconfig :phoenix_copy,\n  default: [\n    source: Path.expand(\"../assets/static/\", __DIR__),\n    destination: Path.expand(\"../priv/static/\", __DIR__),\n    debounce: 100\n  ],\n```\n\nIn this example, files will be copied from `../assets/static/` to `../priv/static/`, two directories relative to the location of the configuration file.\nBy using `Path.expand(..., __DIR__)`, we can be sure that the paths won't change depending on the working directory of the caller.\n\n`debounce` is an optional time in milliseconds to wait before executing the copy.\nMultiple file changes made within the debounce period will result in a single copy event.\n\nIf you need multiple copies to take place, you can add additional profiles:\n\n```elixir\nconfig :phoenix_copy,\n  images: [\n    source: Path.expand(\"../assets/static/images/\", __DIR__),\n    destination: Path.expand(\"../priv/static/images/\", __DIR__)\n  ],\n  docs: [\n    source: Path.expand(\"../docs/\", __DIR__),\n    destination: Path.expand(\"../priv/static/docs/\", __DIR__),\n    debounce: 100\n  ]\n```","ref":"readme.html#configuration","title":"Configuration - Phoenix Copy","type":"extras"},{"doc":"For **one-time copying** of files — for example, when preparing assets for deployment — use `mix phx.copy [profile] [profile2] ...` with the name of the configuration profiles.\nThis can integrate with a mix alias for ease-of-use (for example, in `mix.exs`):\n\n```elixir\ndefp aliases do\n  [\n    \"assets.deploy\": [\n      \"phx.copy default\",\n      \"esbuild default --minify\",\n      \"tailwind default --minify\",\n      \"phx.digest\"\n    ],\n    # ...\n  ]\nend\n```\n\nFor **continuous copying** of files — for example, in development — use `Phoenix.Copy` and the `watch/1` function with the name of the configuration profile.\nThis can integration with Phoenix endpoint configuration for ease-of-use (for example, in `dev.exs`):\n\n```elixir\nconfig :my_app, MyAppWeb.Endpoint,\n  http: [port: 4000],\n  # ...\n  watchers: [\n    asset_copy: {Phoenix.Copy, :watch, [:default]},\n    esbuild: {Esbuild, :install_and_run, [:default, ~w(--sourcemap=inline --watch)]},\n    tailwind: {Tailwind, :install_and_run, [:default, ~w(--watch)]}\n  ]\n```\n\nFor continuously copying multiple profiles at once, use `{Phoenix.Copy, :watch, [[:profile1, :profile2, ...]]}`.","ref":"readme.html#usage","title":"Usage - Phoenix Copy","type":"extras"},{"doc":"This project uses code adapted from the [esbuild](https://github.com/phoenixframework/esbuild) and [tailwind](https://github.com/phoenixframework/tailwind) helpers for Phoenix.\nThose projects, like this one, are licensed under the [MIT License](LICENSE).\nThank you to the contributors of both projects.","ref":"readme.html#acknowledgements","title":"Acknowledgements - Phoenix Copy","type":"extras"},{"doc":"MIT License\n\nCopyright (c) 2022 AJ Foster\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html","title":"LICENSE","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}